@@ -1,12 +1,12 @@
 /*
- * generated Wed Sep 28 18:44:23 MDT 2022
- * on amd64-3.ports.openbsd.org (OpenBSD)
- * by $Id: configure,v 1.421 2020-12-18 22:59:11 phil Exp $
+ * generated Thu Mar 21 08:51:54 MDT 2024
+ * on powerpc64-1.ports.openbsd.org (OpenBSD)
+ * by $Id: configure,v 1.431 2024-01-01 04:06:59 phil Exp $
  */
 
 #define CONFIG_OPTIONS "--prefix=/usr/local --opt=-O2 -pipe  "
-#define CONFIG_HOST "amd64-3.ports.openbsd.org"
-#define CONFIG_DATE "Wed Sep 28 18:44:23 MDT 2022"
+#define CONFIG_HOST "powerpc64-1.ports.openbsd.org"
+#define CONFIG_DATE "Thu Mar 21 08:51:54 MDT 2024"
 #define DIR_SEP "/"
 #define PATH_SEP ":"
 #define OBJECT_EXT ".o"
@@ -33,8 +33,8 @@
 #define HAVE_UTIL_H
 #define HAVE_PATHS_H
 #define SNOLIB_BASE "/usr/local/lib/snobol4"
-#define SNOLIB_DIR "/usr/local/lib/snobol4/2.2.1/lib"
-#define INCLUDE_DIR "/usr/local/lib/snobol4/2.2.1/include"
+#define SNOLIB_DIR "/usr/local/lib/snobol4/2.3.2/lib"
+#define INCLUDE_DIR "/usr/local/lib/snobol4/2.3.2/include"
 #define HAVE_FSEEKO
 #define HAVE_STRFTIME
 #define EXPORT(TYPE) __attribute__ ((__visibility__("default"))) TYPE
